import { debug } from '@linaria/logger';
import hasImport from './hasImport';

function getTemplateTypeByTag(t, path, localName, has) {
  const {
    tag
  } = path.node; // styled(Cmp)``

  if (t.isCallExpression(tag) && t.isIdentifier(tag.callee) && tag.arguments.length === 1 && (tag.callee.name === localName.styled || tag.callee.name === localName.atomicStyled) && (has(localName.styled, ['@linaria/react', 'linaria/react']) || has(localName.atomicStyled, ['@linaria/atomic']))) {
    const tagPath = path.get('tag');
    return {
      component: tagPath.get('arguments')[0],
      type: has(localName.atomicStyled, ['@linaria/atomic']) && tag.callee.name === localName.atomicStyled ? 'atomic-styled' : 'styled'
    };
  } // styled.div``


  if (t.isMemberExpression(tag) && t.isIdentifier(tag.object) && t.isIdentifier(tag.property) && (tag.object.name === localName.styled || tag.object.name === localName.atomicStyled) && (has(localName.styled, ['@linaria/react', 'linaria/react']) || has(localName.atomicStyled, ['@linaria/atomic']))) {
    return {
      component: {
        node: t.stringLiteral(tag.property.name)
      },
      type: has(localName.atomicStyled, ['@linaria/atomic']) && tag.object.name === localName.atomicStyled ? 'atomic-styled' : 'styled'
    };
  } // css``


  if (has(localName.coreCss, ['@linaria/core', 'linaria']) && t.isIdentifier(tag) && tag.name === localName.coreCss) {
    return 'css';
  } // css`` but atomic


  if (has(localName.atomicCss, ['@linaria/atomic']) && t.isIdentifier(tag) && tag.name === localName.atomicCss) {
    return 'atomic-css';
  }

  return null;
}

const cache = new WeakMap();
export default function getTemplateType({
  types: t
}, path, state, libResolver) {
  if (!cache.has(path)) {
    const localName = {
      styled: state.file.metadata.localName?.styled || 'styled',
      coreCss: state.file.metadata.localName?.coreCss || 'css',
      atomicCss: state.file.metadata.localName?.atomicCss || 'css',
      atomicStyled: state.file.metadata.localName?.atomicStyled || 'styled'
    };

    const has = (identifier, sources) => hasImport(t, path.scope, state.file.opts.filename, identifier, sources, libResolver);

    const templateType = getTemplateTypeByTag(t, path, localName, has);
    debug('get-template-type:template-type', templateType);
    cache.set(path, getTemplateTypeByTag(t, path, localName, has));
  }

  return cache.get(path) ?? null;
}
//# sourceMappingURL=getTemplateType.js.map