"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getTemplateType;

var _logger = require("@linaria/logger");

var _hasImport = _interopRequireDefault(require("./hasImport"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getTemplateTypeByTag(t, path, localName, has) {
  const {
    tag
  } = path.node; // styled(Cmp)``

  if (t.isCallExpression(tag) && t.isIdentifier(tag.callee) && tag.arguments.length === 1 && (tag.callee.name === localName.styled || tag.callee.name === localName.atomicStyled) && (has(localName.styled, ['@linaria/react', 'linaria/react']) || has(localName.atomicStyled, ['@linaria/atomic']))) {
    const tagPath = path.get('tag');
    return {
      component: tagPath.get('arguments')[0],
      type: has(localName.atomicStyled, ['@linaria/atomic']) && tag.callee.name === localName.atomicStyled ? 'atomic-styled' : 'styled'
    };
  } // styled.div``


  if (t.isMemberExpression(tag) && t.isIdentifier(tag.object) && t.isIdentifier(tag.property) && (tag.object.name === localName.styled || tag.object.name === localName.atomicStyled) && (has(localName.styled, ['@linaria/react', 'linaria/react']) || has(localName.atomicStyled, ['@linaria/atomic']))) {
    return {
      component: {
        node: t.stringLiteral(tag.property.name)
      },
      type: has(localName.atomicStyled, ['@linaria/atomic']) && tag.object.name === localName.atomicStyled ? 'atomic-styled' : 'styled'
    };
  } // css``


  if (has(localName.coreCss, ['@linaria/core', 'linaria']) && t.isIdentifier(tag) && tag.name === localName.coreCss) {
    return 'css';
  } // css`` but atomic


  if (has(localName.atomicCss, ['@linaria/atomic']) && t.isIdentifier(tag) && tag.name === localName.atomicCss) {
    return 'atomic-css';
  }

  return null;
}

const cache = new WeakMap();

function getTemplateType({
  types: t
}, path, state, libResolver) {
  var _cache$get;

  if (!cache.has(path)) {
    var _state$file$metadata$, _state$file$metadata$2, _state$file$metadata$3, _state$file$metadata$4;

    const localName = {
      styled: ((_state$file$metadata$ = state.file.metadata.localName) === null || _state$file$metadata$ === void 0 ? void 0 : _state$file$metadata$.styled) || 'styled',
      coreCss: ((_state$file$metadata$2 = state.file.metadata.localName) === null || _state$file$metadata$2 === void 0 ? void 0 : _state$file$metadata$2.coreCss) || 'css',
      atomicCss: ((_state$file$metadata$3 = state.file.metadata.localName) === null || _state$file$metadata$3 === void 0 ? void 0 : _state$file$metadata$3.atomicCss) || 'css',
      atomicStyled: ((_state$file$metadata$4 = state.file.metadata.localName) === null || _state$file$metadata$4 === void 0 ? void 0 : _state$file$metadata$4.atomicStyled) || 'styled'
    };

    const has = (identifier, sources) => (0, _hasImport.default)(t, path.scope, state.file.opts.filename, identifier, sources, libResolver);

    const templateType = getTemplateTypeByTag(t, path, localName, has);
    (0, _logger.debug)('get-template-type:template-type', templateType);
    cache.set(path, getTemplateTypeByTag(t, path, localName, has));
  }

  return (_cache$get = cache.get(path)) !== null && _cache$get !== void 0 ? _cache$get : null;
}
//# sourceMappingURL=getTemplateType.js.map