"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = DetectLinariaImportName;

/* eslint-disable no-param-reassign */

/**
 * This Visitor checks if import of `@linaria/react` was renamed and stores that information in state
 */
function getLocalImportName({
  types: t
}, path, importedName) {
  let localName = undefined;
  path.node.specifiers.forEach(specifier => {
    if (!t.isImportSpecifier(specifier)) {
      return;
    }

    const specifierImportedName = t.isStringLiteral(specifier.imported) ? specifier.imported.value : specifier.imported.name; // If we're checking for a specific import's local name, only look at that import specifier.

    if (importedName && specifierImportedName !== importedName) {
      return;
    }

    if (specifier.local.name !== specifierImportedName) {
      localName = specifier.local.name;
    }
  });
  return localName;
}

function DetectLinariaImportName(core, path, state) {
  const {
    types: t
  } = core;

  if (t.isLiteral(path.node.source, {
    value: '@linaria/react'
  })) {
    const localImportName = getLocalImportName(core, path);

    if (localImportName) {
      var _state$file$metadata;

      (_state$file$metadata = state.file.metadata).localName || (_state$file$metadata.localName = {});
      state.file.metadata.localName.styled = localImportName;
    }
  } else if (t.isLiteral(path.node.source, {
    value: '@linaria/core'
  }) || t.isLiteral(path.node.source, {
    value: 'linaria'
  })) {
    const localImportName = getLocalImportName(core, path, 'css');

    if (localImportName) {
      var _state$file$metadata2;

      (_state$file$metadata2 = state.file.metadata).localName || (_state$file$metadata2.localName = {});
      state.file.metadata.localName.coreCss = localImportName;
    }
  } else if (t.isLiteral(path.node.source, {
    value: '@linaria/atomic'
  })) {
    const localImportName = getLocalImportName(core, path, 'css');

    if (localImportName) {
      var _state$file$metadata3;

      (_state$file$metadata3 = state.file.metadata).localName || (_state$file$metadata3.localName = {});
      state.file.metadata.localName.atomicCss = localImportName;
    } else {
      const localImportName = getLocalImportName(core, path);

      if (localImportName) {
        var _state$file$metadata4;

        (_state$file$metadata4 = state.file.metadata).localName || (_state$file$metadata4.localName = {});
        state.file.metadata.localName.atomicStyled = localImportName;
      }
    }
  }
}
//# sourceMappingURL=DetectLinariaImportName.js.map